# 2022-05-30 - Preseeded Voting Escrow Delegation

Deployment of the Preseeded Voting Escrow Delegation, a replacement for the original Voting Escrow Delegation. This implementation is identical to the first one, except an account has been approved to act in Tribe DAO's stead, and it has been preseeded with all boosts previously created.

See [the Tribe DAO proposal](https://forum.balancer.fi/t/tribe-dao-boost-delegation/3218) for more context.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Goerli testnet addresses](./output/goerli.json)
- [Sepolia testnet addresses](./output/sepolia.json)
- [`PreseededVotingEscrowDelegation` artifact](./artifact/PreseededVotingEscrowDelegation.json)
